@@ -133,9 +133,6 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
                     f.write(F"{key}")
                 except:
                     pass
-            if PRINT == True:
-                print(key)
-                break
             PRINT = True
             # box = F'''
             # ╔═╗
